function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var hljs = _interopDefault(require('highlight.js'));
var prettyBytes = _interopDefault(require('pretty-bytes'));
require('react-virtualized/styles.css');
var classNames = _interopDefault(require('classnames'));
var reactVirtualized = require('react-virtualized');

var styles = {"container":"_1Lxpd","header":"_1aDvk","body":"_2mo3X","num":"_1H33u","code":"_1NqbF","codeInner":"_2Dc72","highlighted":"_CLeTf"};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var NumberCell = function NumberCell(_ref) {
  var lineNumber = _ref.lineNumber,
      onClick = _ref.onClick;
  return React.createElement("td", {
    id: "L" + lineNumber,
    key: "col-line-number-" + lineNumber,
    "data-line-number": lineNumber,
    className: styles.num,
    onClick: onClick
  });
};

var NumberCell$1 = React.memo(NumberCell);

var CodeCell = function CodeCell(_ref) {
  var lineNumber = _ref.lineNumber,
      code = _ref.code,
      isHighlight = _ref.isHighlight;

  var _React$useState = React.useState(styles.code + " " + styles.codeInner),
      className = _React$useState[0],
      setClassName = _React$useState[1];

  React.useEffect(function () {
    var _classNames;

    setClassName(classNames(styles.code, styles.codeInner, (_classNames = {}, _classNames[styles.highlighted] = isHighlight, _classNames)));
  }, [isHighlight]);
  return React.createElement("td", {
    id: "LC" + lineNumber,
    key: "col-code-" + lineNumber,
    className: className,
    dangerouslySetInnerHTML: {
      __html: code
    }
  });
};

var CodeCell$1 = React.memo(CodeCell);

var Row = function Row(_ref) {
  var style = _ref.style,
      row = _ref.row,
      showLineNumber = _ref.showLineNumber,
      onClick = _ref.onClick;
  var lineNumber = row.lineNumber;
  var handleClick = React.useCallback(function (event) {
    onClick && onClick(lineNumber, event);
  }, []);
  return React.createElement("tr", {
    style: _extends({}, style, {
      width: "100%",
      overflow: "initial"
    })
  }, showLineNumber && React.createElement(NumberCell$1, {
    lineNumber: lineNumber,
    onClick: handleClick
  }), React.createElement(CodeCell$1, {
    lineNumber: lineNumber,
    code: row.content,
    isHighlight: row.isHighlight
  }));
};

var Row$1 = React.memo(Row);

var CodeContainer = function CodeContainer(_ref) {
  var code = _ref.code,
      language = _ref.language,
      _ref$showLineNumber = _ref.showLineNumber,
      showLineNumber = _ref$showLineNumber === void 0 ? true : _ref$showLineNumber,
      _ref$selectedLines = _ref.selectedLines,
      selectedLines = _ref$selectedLines === void 0 ? [] : _ref$selectedLines,
      onLineNumberClick = _ref.onLineNumberClick,
      onUnSelect = _ref.onUnSelect;

  var _React$useState = React.useState(selectedLines),
      lines = _React$useState[0],
      setLines = _React$useState[1];

  var _React$useState2 = React.useState([]),
      codes = _React$useState2[0],
      setCodes = _React$useState2[1];

  var linesRef = React.useRef(lines);
  React.useEffect(function () {
    if (!!language && hljs.getLanguage(language || '')) {
      setCodes(hljs.highlight(language, code).value.split('\n'));
    } else {
      setCodes(hljs.highlightAuto(code).value.split('\n'));
    }
  }, [code, language]);
  var handleUnSelect = React.useCallback(function (event) {
    if (event.key === 'Escape') {
      setLines([]);
      linesRef.current = [];
      onUnSelect && onUnSelect();
    }
  }, []);
  React.useEffect(function () {
    document.body.addEventListener('keydown', handleUnSelect);
    return function () {
      document.body.removeEventListener('keydown', handleUnSelect);
    };
  }, []);
  var getSloc = React.useCallback(function () {
    return code.split('\n').filter(function (line) {
      return line.trim().length > 0;
    }).length;
  }, [code]);
  var getSize = React.useCallback(function () {
    return prettyBytes(new Blob([code]).size);
  }, [code]);

  var onClickLine = function onClickLine(lineNumber, event) {
    var tmpLines = [lineNumber];

    if (event.shiftKey) {
      var firstSelectedLine = linesRef.current[0];
      var range = firstSelectedLine - lineNumber;
      var n = 1;

      while (n <= Math.abs(range)) {
        var index = range > 0 ? lineNumber + n : lineNumber - n;
        tmpLines.push(index);
        n++;
      }
    }

    var sortLines = tmpLines.sort(function (a, b) {
      return a - b;
    });
    setLines(sortLines);
    linesRef.current = sortLines;
    onLineNumberClick && onLineNumberClick(lineNumber, sortLines);
  };

  var rowRenderer = function rowRenderer(_ref2) {
    var index = _ref2.index,
        key = _ref2.key,
        style = _ref2.style;
    var isHighlight = !!lines.find(function (lineNumber) {
      return lineNumber === index + 1;
    });
    var row = {
      lineNumber: index + 1,
      content: codes[index],
      isHighlight: isHighlight
    };
    return React.createElement(Row$1, {
      key: key,
      row: row,
      style: style,
      showLineNumber: showLineNumber,
      onClick: onClickLine
    });
  };

  return React.createElement(reactVirtualized.WindowScroller, null, function (_ref3) {
    var height = _ref3.height,
        isScrolling = _ref3.isScrolling,
        onChildScroll = _ref3.onChildScroll,
        scrollTop = _ref3.scrollTop;
    return React.createElement("div", {
      className: styles.container
    }, React.createElement("div", {
      className: styles.header
    }, React.createElement("div", null, codes.length, " lines (", getSloc(), " sloc) | ", getSize())), React.createElement("div", {
      className: styles.body + " hljs"
    }, React.createElement(reactVirtualized.AutoSizer, {
      disableHeight: true
    }, function (_ref4) {
      var width = _ref4.width;
      return React.createElement(reactVirtualized.Table, {
        width: width,
        height: height,
        gridClassName: styles.codeTable,
        autoHeight: true,
        headerHeight: 0,
        rowHeight: 20,
        rowCount: codes.length,
        rowRenderer: rowRenderer,
        overscanRowCount: 20,
        scrollTop: scrollTop,
        onScroll: onChildScroll,
        isScrolling: isScrolling,
        rowGetter: function rowGetter(_ref5) {
          var index = _ref5.index;
          return codes[index];
        }
      });
    })));
  });
};

exports.CodeContainer = CodeContainer;
exports.default = CodeContainer;
//# sourceMappingURL=index.js.map
